@@ -1,15 +1,17 @@
 from rich import traceback
 from pathlib import Path
-from rich import print
 import shutil as sh
 import platform
+import rich
 import sys
 import os
 
 
-version = '22.0.8'
+version = '22.0.9'
 proj_path = Path(__file__).parent.resolve()
 icon_ico_source = f'{proj_path}/icon.ico'
+c = rich.console.Console()
+print = c.print
 if 'portable' in sys.argv:
     portable = True
 
